@@ -1,9 +1,10 @@
 class DeployResultModel(object):
-    def __init__(self, vm_name, vm_uuid, cloud_provider_name, deployed_app_ip, deployed_app_attributes,
+    def __init__(self, vm_name, vm_uuid, deployed_app_ip, deployed_app_attributes,
                  floating_ip, vm_details_data):
         self.vm_name = vm_name
         self.vm_uuid = vm_uuid
-        self.cloud_provider_resource_name = cloud_provider_name
+        # Remove cloud_provider_resource_name from result. We already populate this on the server side automatically
+        # self.cloud_provider_resource_name = cloud_provider_name
         # self.autoload = autoload
         # self.auto_delete = autodelete
         self.wait_for_ip = False
